<?php
/**
 * The Vilma script to add/edit users.
 *
 * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
 *
 * See the enclosed file LICENSE for license information (BSD). If you did not
 * receive this file, see http://cvs.horde.org/co.php/vilma/LICENSE.
 *
 * $Horde: vilma/users/edit.php,v 1.22 2005/01/03 14:35:42 jan Exp $
 */

@define('VILMA_BASE', dirname(__FILE__) . '/..');
require_once VILMA_BASE . '/lib/base.php';
require_once 'Horde/Form.php';
require_once 'Horde/Variables.php';

/* Only admin should be using this. */
if (!Auth::isAdmin() && !Vilma::isDomainAdmin()) {
    Horde::authenticationFailureRedirect();
}

$vars = &Variables::getDefaultVariables();
$user_id = $vars->get('user_id');
$domain = Vilma::getDomain();

$form = &Horde_Form::singleton('', $vars);

/* Check if a form is being edited. */
$editing = false;
if ($user_id && !$form->isSubmitted()) {
    $vars = &new Variables($vilma->getUser($user_id));
    $user_name = $vars->get('user_name');
    $domain = Vilma::stripDomain($user_name);
    $vars->set('user_name', Vilma::stripUser($user_name));
    $vars->set('domain', $domain);
    $editing = true;
}

if (!$user_id && !$vilma->isBelowMaxUsers($domain)) {
    $notification->push(sprintf(_("'%s' already has the maximum number of users allowed."), $domain), 'horde.error');
    require VILMA_BASE . '/users/index.php';
    exit;
}

$title = ($editing) ? sprintf(_("Edit User for '%s'"), $domain) : sprintf(_("New User for '%s'"), $domain);
$form->setTitle($title);

/* Set up the form. */
$form->setButtons(true, true);
$form->addHidden('', 'user_id', 'text', false);
$form->addHidden('', 'domain', 'text', false);
$form->addVariable(_("User"), 'user_name', 'text', true, false, _("Name must begin with an alphanumerical character, it must contain only alphanumerical and '._-' characters, and must end with an alphanumerical character."), array('~^[a-zA-Z0-9]{1,1}[a-zA-Z0-9._-]*[a-zA-Z0-9]$~'));
if ($user_id) {
    $form->addVariable(_("Password"), 'password', 'passwordconfirm', false, false, _("Only enter a password if you wish to change this user's password"));
} else {
    $form->addVariable(_("Password"), 'password', 'passwordconfirm', true);
}
$form->addVariable(_("Name"), 'user_full_name', 'text', true);
$v = &$form->addVariable(_("Enabled?"), 'user_enabled', 'radio', false, false, null, array(array(1 => _("User is enabled"),
                 0 => _("User is disabled"))));
$v->setDefault(1);

if ($form->validate($vars)) {
    $form->getInfo($vars, $info);
    $info['user_name'] = String::lower($info['user_name']) . '@' . $domain;
    $user_id = $vilma->saveUser($info);
    if (is_a($user_id, 'PEAR_Error')) {
        Horde::logMessage($user_id, __FILE__, __LINE__, PEAR_LOG_ERR);
        $notification->push(sprintf(_("Error saving user. %s"), $user_id->getMessage()), 'horde.error');
    } else {
        $notification->push(_("User details saved."), 'horde.success');
        $virtuals = $vilma->getVirtuals($info['user_name']);
        if (count($virtuals)) {
            /* User has virtual email addresses set up. */
            $url = Horde::applicationUrl('users/index.php', true);
            header('Location: ' . (Vilma::isDomainAdmin() ? $url : Util::addParameter($url, 'domain', $domain)));
        } else {
            /* User does not have any virtual email addresses set up. */
            $notification->push(_("No virtual email address set up for this user. You should set up at least one virtual email address if this user is to receive any emails."), 'horde.warning');
            $url = Horde::applicationUrl('virtuals/edit.php', true);
            $url = Util::addParameter($url, array('domain' => $domain, 'stripped_email' => Vilma::stripUser($info['user_name']), 'destination' => $info['user_name']));
            header('Location: ' . (Vilma::isDomainAdmin() ? $url : Util::addParameter($url, 'domain', $domain)));
        }
        exit;
    }
}

/* Render the form. */
require_once 'Horde/Form/Renderer.php';
$renderer = &new Horde_Form_Renderer();
$main = Util::bufferOutput(array($form, 'renderActive'), $renderer, $vars, 'edit.php', 'post');

$template->set('main', $main);
$template->set('menu', Vilma::getMenu('string'));
$template->set('notify', Util::bufferOutput(array($notification, 'notify'), array('listeners' => 'status')));

require VILMA_TEMPLATES . '/common-header.inc';
echo $template->fetch(VILMA_TEMPLATES . '/main/main.html');
require $registry->get('templates', 'horde') . '/common-footer.inc';
